@@ -26,7 +26,8 @@ has rangeRegex => (
   is      => 'ro',
   default => sub {
     my $self = shift;
-    return qr/^(?:(?:25[0-5]|2[0-4][0-9]|[0-1]?[0-9]{1,2})\.){3}(?:25[0-5]|2[0-4][0-9]|[0-1]?[0-9]{1,2})-(?:(?:25[0-5]|2[0-4][0-9]|[0-1]?[0-9]{1,2})\.){3}(?:25[0-5]|2[0-4][0-9]|[0-1]?[0-9]{1,2})$/;
+    return
+      qr/^(?:(?:25[0-5]|2[0-4][0-9]|[0-1]?[0-9]{1,2})\.){3}(?:25[0-5]|2[0-4][0-9]|[0-1]?[0-9]{1,2})-(?:(?:25[0-5]|2[0-4][0-9]|[0-1]?[0-9]{1,2})\.){3}(?:25[0-5]|2[0-4][0-9]|[0-1]?[0-9]{1,2})$/;
   },
 );
 
@@ -37,7 +38,8 @@ has subRangeRegex => (
   is      => 'ro',
   default => sub {
     my $self = shift;
-    return qr/^(?:(?:25[0-5]|2[0-4][0-9]|[0-1]?[0-9]{1,2})\.){3}(?:25[0-5]|2[0-4][0-9]|[0-1]?[0-9]{1,2})-(?:25[0-5]|2[0-4][0-9]|[0-1]?[0-9]{1,2})$/;
+    return
+      qr/^(?:(?:25[0-5]|2[0-4][0-9]|[0-1]?[0-9]{1,2})\.){3}(?:25[0-5]|2[0-4][0-9]|[0-1]?[0-9]{1,2})-(?:25[0-5]|2[0-4][0-9]|[0-1]?[0-9]{1,2})$/;
   },
 );
 
@@ -48,7 +50,8 @@ has ipMask => (
   is      => 'ro',
   default => sub {
     my $self = shift;
-    return qr/^(?:(?:25[0-5]|2[0-4][0-9]|[0-1]?[0-9]{1,2})\.){3}(?:25[0-5]|2[0-4][0-9]|[0-1]?[0-9]{1,2})\/(?:[1-9]|[12][0-9]|3[0-2])$/;
+    return
+      qr/^(?:(?:25[0-5]|2[0-4][0-9]|[0-1]?[0-9]{1,2})\.){3}(?:25[0-5]|2[0-4][0-9]|[0-1]?[0-9]{1,2})\/(?:[1-9]|[12][0-9]|3[0-2])$/;
   },
 );
 
@@ -59,7 +62,8 @@ has ipRange => (
   is      => 'ro',
   default => sub {
     my $self = shift;
-    return qr/(^(?:(?:25[0-5]|2[0-4][0-9]|[0-1]?[0-9]{1,2})\.){3}(?:25[0-5]|2[0-4][0-9]|[0-1]?[0-9]{1,2})-(?:25[0-5]|2[0-4][0-9]|[0-1]?[0-9]{1,2})$)|(^(?:(?:25[0-5]|2[0-4][0-9]|[0-1]?[0-9]{1,2})\.){3}(?:25[0-5]|2[0-4][0-9]|[0-1]?[0-9]{1,2})-(?:(?:25[0-5]|2[0-4][0-9]|[0-1]?[0-9]{1,2})\.){3}(?:25[0-5]|2[0-4][0-9]|[0-1]?[0-9]{1,2})$)/;
+    return
+      qr/(^(?:(?:25[0-5]|2[0-4][0-9]|[0-1]?[0-9]{1,2})\.){3}(?:25[0-5]|2[0-4][0-9]|[0-1]?[0-9]{1,2})-(?:25[0-5]|2[0-4][0-9]|[0-1]?[0-9]{1,2})$)|(^(?:(?:25[0-5]|2[0-4][0-9]|[0-1]?[0-9]{1,2})\.){3}(?:25[0-5]|2[0-4][0-9]|[0-1]?[0-9]{1,2})-(?:(?:25[0-5]|2[0-4][0-9]|[0-1]?[0-9]{1,2})\.){3}(?:25[0-5]|2[0-4][0-9]|[0-1]?[0-9]{1,2})$)/;
   },
 );
 
@@ -70,7 +74,7 @@ sub getRangeFromIpRange {
   my ( $self, $ipMin, $ipMax ) = @_;
   # 入参检查
   confess __PACKAGE__ . "必须提供 ipRange (min, max)"
-    unless (defined $ipMin and defined $ipMax);
+    unless ( defined $ipMin and defined $ipMax );
 
   my $min = $self->changeIpToInt($ipMin);
   my $max = $self->changeIpToInt($ipMax);
@@ -86,7 +90,7 @@ sub getRangeFromIpMask {
   my ( $self, $ip, $mask ) = @_;
 
   # 匹配 1.1.1.1-2.2.2.2 样式
-  if ( $ip =~ $self->rangeRegex ){
+  if ( $ip =~ $self->rangeRegex ) {
     my ( $min, $max ) = split( /-/, $ip );
     return $self->getRangeFromIpRange( $min, $max );
   }
